@@ -110,9 +110,9 @@ def _format(response):
         'status_detail': response['status_detail'],
         'card': _format_card(response),
         'payment_day': date,
-        'statement_descriptor': '',
-        'payment_method_id': '',
-        'installments': ''
+        'statement_descriptor': response['establishment_name'],
+        'payment_method_id': response['payment_method_id'],
+        'installments': response['installments'],
     }
     return result
 
